function [dy]=lorenz(t,y)
% Lorenz Equations
% 
% dx_dt = sigma(y-x)
% dy_dt = x(rho-z)-y
% dz_dt = x*y-beta*z
%
% Input arguments x, y, z and t 
% Output arguments dx_dt, dy_dt and dz_dt
%
% Constants
rho = 28; 
sigma = 10; 
beta = 8/3; 

% initialize 
dy = zeros(3,1);

% evaluate
dy(1) = sigma*(y(2)-y(1));
dy(2) = y(1)*(rho-y(3))-y(2);
dy(3) = y(1)*y(2)-beta*y(3);



