% Solve a first order ODE with a known exact solution
% compare numerical methods for solution to the known 
%
% First order ODE: 
% dy/dt = -b*y
%
% Exact solution
% y = y0*exp(-b*t);
%
b = 0.2;
% Initial condition
y0 = 1; 
%
% Integrate from t0 to tfinal
t0 = 0; 
tfinal = 6; 
%stepsize
dt = 0.1; 
tspan = [t0:dt:tfinal];
 
% using the inbuilt matlab ode45 routine: 
%[T45,Y45]=ode45(@exampleFirstOrderODE,tspan,y0);
% plot the output
%figure(100);
%plot(T45,Y45,'g o');

% using the ode options 
%  tspan = [t0,tfinal];
options=odeset('RelTol',1e-8);
[T45,Y45] = ode45(@exampleFirstOrderODE,[t0,tfinal],y0,options);

% plot the output
figure(100);
plot(T45,Y45,'c o');

% using the inbuilt matlab ode23 routine: 
%[T23,Y23]=ode23(@exampleFirstOrderODE,tspan,y0);

% plot the output
%figure(100);
%plot(T23,Y23,'g o');

% initialize stuff
 yeul = zeros(1,length(tspan));
 yeul(1)=y0; 
% 
% Euler
 for ii=2:1:length(tspan)
     yeul(ii)=yeul(ii-1)+dt*exampleFirstOrderODE(tspan(ii-1),yeul(ii-1));
 end
 
% plot 
 
figure(100);
hold; 
plot(tspan,yeul,'k o');
hold;
 

% compare to the exact solution
%b = 0.2;
%y0 = 1; 
Texact = [t0:0.1:tfinal]; 
yexact = y0*exp(-b*Texact);

% plot the output on the same figure
figure(100); 
hold; 
plot(Texact,yexact,'-r'); 
hold; 
xlabel('t');
ylabel('y');

%legend('ode45','Exact');
%legend('ode23','Exact');
%legend('Euler','Exact');